using SoapEndpoint.Service.Flows.BrEnHf.v1.LogbookService;
using SoapEndpoint.Service.Proxy.Models.Systeem;
using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v2.ErrorMessage;
using SoapEndpoint.Tester.Scenario.Flow.BrEnHf;

namespace SoapEndpoint.Tester.Scenario.Implementations.BrEnHf;

public class SeSectorPubliekScenario : BrEnHfScenarioBase
{
    public override string Name => "SE sector publiek scenario";

    public override AdresboekOrganisatieModel SeOrganization =>
        Manager.Organizations.SingleOrDefault(p => p.Referentienummer.ToString()
            .Equals(Program.Configuration["SeGovernmentTestOrganizationReference"],
                StringComparison.CurrentCultureIgnoreCase));

    protected override async Task ExecuteAsync()
    {
        StartNewScenario("Happy flow - Regeling geaccordeerd 1");
        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek, BerichtType.SE_KennisgevingAntwoord),
            new ShvFlowItem(BerichtType.SHV_SaldoverzoekPubliek, BerichtType.SE_SaldoverzoekAntwoord),
            new ShvFlowItem(BerichtType.SHV_Betaalvoorstel, BerichtType.SE_BetaalvoorstelAntwoordAkkoord),
            new ShvFlowItem(BerichtType.SHV_RegelingGeaccordeerd));

        StartNewScenario("Happy flow - Regeling geaccordeerd 2");
        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_SaldoverzoekPubliek, BerichtType.SE_SaldoverzoekAntwoord),
            new ShvFlowItem(BerichtType.SHV_Betaalvoorstel, BerichtType.SE_BetaalvoorstelAntwoordAkkoord),
            new ShvFlowItem(BerichtType.SHV_RegelingGeaccordeerd));

        StartNewScenario("Foutsituatie kennisgeving");
        await Manager.SHV_SendIncorrectMessageAsync(Conversation, BerichtType.SHV_Kennisgeving, null,
            ShvKnooppuntFoutcode.Incorrectberichttypevoorsectorvanontvanger);

        await SendInvalidSaldoverzoek();
    }

    private async Task SendInvalidSaldoverzoek()
    {
        var messageTypes = new List<BerichtType>
        {
            BerichtType.SHV_SaldoverzoekZorg,
            BerichtType.SHV_Saldoverzoek,
            BerichtType.SHV_SaldoverzoekNuts
        };

        foreach (var messageType in messageTypes)
        {
            StartNewScenario($"Foutsituatie: {messageType}");

            await Manager.SHV_SendIncorrectMessageAsync(Conversation, messageType, null,
                ShvKnooppuntFoutcode.Incorrectberichttypevoorsectorvanontvanger);
        }
    }
}