﻿using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v1.ErrorMessage;
using SoapEndpoint.Service.Systeem.v1.LogbookService;
using SoapEndpoint.Tester.Scenario.Flow.Schuldbemiddeling;

namespace SoapEndpoint.Tester.Scenario.Implementations.Schuldbemiddeling;

public class SchuldregelingBeeindigdScenario : SchuldbemiddelingScenarioBase
{
    public override string Name => "Schuldregeling beeindigd scenario";

    protected override async Task ExecuteAsync()
    {
        StartNewScenario("Schuldregeling beeindigd na saldoverzoek");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord),
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek),
            new ShvFlowItem(Berichttype.SHV_SchuldregelingBeeindigd));

        StartNewScenario("Schuldregeling beeindigd na saldoverzoek antwoord");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord),
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek, Berichttype.SE_SaldoverzoekAntwoord),
            new ShvFlowItem(Berichttype.SHV_SchuldregelingBeeindigd));

        StartNewScenario("Schuldregeling beeindigd na betaalvoorstel");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord),
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek, Berichttype.SE_SaldoverzoekAntwoord),
            new ShvFlowItem(Berichttype.SHV_Betaalvoorstel),
            new ShvFlowItem(Berichttype.SHV_SchuldregelingBeeindigd));

        StartNewScenario("Schuldregeling beeindigd na betaalvoorstel antwoord");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord),
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek, Berichttype.SE_SaldoverzoekAntwoord),
            new ShvFlowItem(Berichttype.SHV_Betaalvoorstel, Berichttype.SE_BetaalvoorstelAntwoord),
            new ShvFlowItem(Berichttype.SHV_SchuldregelingBeeindigd));

        StartNewScenario("Fout: schuldregeling beeindigd na klantgemeld voor shv");

        await Manager.SHV_FlowAsync(Conversation, null, new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv));

        // Send schuldregeling beeindigd (not allowed)
        await Manager.SHV_SendMessageAsync(Conversation, Berichttype.SHV_SchuldregelingBeeindigd);

        // Check that the correct error is returned.
        await Manager.SHV_GetAndConfirmErrorMessage<ShvKnooppuntFoutbericht, Berichttype, ShvKnooppuntFoutcode>(
            Conversation,
            Berichttype.SYS_FoutBericht,
            ShvKnooppuntFoutcode.Berichttypeniettoegestaanvoordehuidigestaatvandeconversatie);

        StartNewScenario("Fout: schuldregeling beeindigd na klantgemeld voor shv antwoord");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord));

        // Send schuldregeling beeindigd (not allowed)
        await Manager.SHV_SendMessageAsync(Conversation, Berichttype.SHV_SchuldregelingBeeindigd);

        // Check that the correct error is returned. 
        await Manager.SHV_GetAndConfirmErrorMessage<ShvKnooppuntFoutbericht, Berichttype, ShvKnooppuntFoutcode>(
            Conversation,
            Berichttype.SYS_FoutBericht,
            ShvKnooppuntFoutcode.Berichttypeniettoegestaanvoordehuidigestaatvandeconversatie);
    }
}