﻿using System.Xml.Linq;
using System.Xml.Schema;

namespace Infrastructure.Utils.Xml;

public class XmlValidationResult
{
    public XmlValidationResult(XDocument xmlDocument, IList<ValidationEventArgs> items)
    {
        XmlDocument = xmlDocument;

        foreach (var item in items)
        {
            if (item.Severity == XmlSeverityType.Warning)
            {
                Warnings.Add(item.Message);
            }

            if (item.Severity == XmlSeverityType.Error)
            {
                Errors.Add(item.Message);
            }
        }
    }

    public bool Success => Errors?.Any() == false && Warnings?.Any() == false;
    public string XsdName { get; }
    public string Xml => XmlDocument?.ToString() ?? string.Empty;
    public XDocument XmlDocument { get; }
    public IList<string> Warnings { get; set; } = new List<string>();
    public IList<string> Errors { get; set; } = new List<string>();
}