using AutoMapper;
using SoapEndpoint.Service.Flows.Schuldbemiddeling.v1.SeService;
using SoapEndpoint.Service.Flows.Schuldbemiddeling.v1.ShvService;
using SoapEndpoint.Service.Proxy.Models.Flows;
using SoapEndpoint.Service.Proxy.Models.Systeem;
using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v1.ErrorMessage;
using SoapEndpoint.Service.Systeem.v1.AddressService;
using SoapEndpoint.Service.Systeem.v1.LogbookService;
using SoapEndpoint.Service.Systeem.v1.MessageBoxService;
using static SoapEndpoint.Service.Proxy.Infrastructure.MappingHelper;
using Adres = SoapEndpoint.Service.Systeem.v1.AddressService.Adres;
using Contactpersoon = SoapEndpoint.Service.Systeem.v1.AddressService.Contactpersoon;
using ShvKnooppuntBerichtBevestiging = SoapEndpoint.Service.Flows.Schuldbemiddeling.v1.ShvService.ShvKnooppuntBerichtBevestiging;
using ShvKnooppuntFout =
    SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v1.ErrorMessage.ShvKnooppuntFout;

namespace SoapEndpoint.Service.Proxy;

public class MappingProfileV1 : Profile
{
    public MappingProfileV1()
    {
        AllowNullCollections = true;

        CreateMap<UpdateOrganisatieBericht, UpdateOrganisatieBerichtModel>()
            .ReverseMap();

        CreateMap<AdresboekZoekbericht, AdresboekZoekBerichtModel>()
            .ForMember(o => o.BerichtSE, cfg => cfg.Ignore())
            .ForMember(o => o.OrganisatieType,
                cfg => cfg.MapFrom(src => MapAddressOrganisatieType(src.OrganisatieType)))
            .ReverseMap();
        CreateMap<AdresboekOrganisatie, AdresboekOrganisatieModel>()
            .ForMember(o => o.BerichtSE, cfg => cfg.Ignore())
            .ForMember(o => o.OrganisatieType,
                cfg => cfg.MapFrom(src => MapAddressOrganisatieType(src.OrganisatieType)))
            .ForMember(o => o.OndersteundeFlows,
                cfg => cfg.MapFrom(o => new List<OrganizationFlowModel>
                    { new(FlowType.Schuldbemiddeling, o.OndersteundeVersies) }))
            .ForMember(o => o.Vtlb, cfg => cfg.MapFrom(src => default(bool?)))
            .ForMember(o => o.Toestemmingsverklaring, cfg => cfg.MapFrom(src => default(bool?)))
            .ForMember(o => o.RedenGeblokkeerd, cfg => cfg.Ignore())
            .ReverseMap();

        CreateMap<Adres, AdresModel>().ReverseMap();
        CreateMap<Contactpersoon, ContactpersoonModel>().ReverseMap();

        // Schuldbemiddeling
        CreateMap<BerichtHeaderSHV, BerichtHeaderModel>()
            .ForMember(x => x.Bijlages, cfg => cfg.Ignore())
            .ReverseMap();
        CreateMap<ShvBericht, BerichtModel<Berichttype>>().ReverseMap();
        CreateMap<ShvKnooppuntBerichtBevestiging,
                ShvKnooppuntBerichtBevestigingModel>()
            .ForMember(x => x.Errors, cfg => cfg.Ignore())
            .ForMember(x => x.ErrorCodes, cfg => cfg.Ignore())
            .ReverseMap();
        CreateMap<Flows.Schuldbemiddeling.v1.ShvService.ShvKnooppuntFout, ShvKnooppuntFoutModel>().ReverseMap();

        CreateMap<BerichtHeaderSE, BerichtHeaderModel>()
            .ForMember(x => x.Ontvanger, cfg => cfg.Ignore())
            .ForMember(x => x.Bijlages, cfg => cfg.Ignore())
            .ReverseMap();
        CreateMap<SeBericht, BerichtModel<Berichttype>>().ReverseMap();
        CreateMap<Flows.Schuldbemiddeling.v1.SeService.ShvKnooppuntBerichtBevestiging,
                ShvKnooppuntBerichtBevestigingModel>()
            .ForMember(x => x.Errors, cfg => cfg.Ignore())
            .ForMember(x => x.ErrorCodes, cfg => cfg.Ignore())
            .ReverseMap();
        CreateMap<Flows.Schuldbemiddeling.v1.SeService.ShvKnooppuntFout,
                ShvKnooppuntFoutModel>()
            .ReverseMap();

        CreateMap<LogboekZoekbericht, LogboekZoekberichtModel>()
            .ForMember(l => l.AfzenderOrganisatieType,
                cfg => cfg.MapFrom(src => MapLogbookOrganisatieType(src.AfzenderOrganisatieType)))
            .ForMember(l => l.OntvangerOrganisatieType,
                cfg => cfg.MapFrom(src => MapLogbookOrganisatieType(src.OntvangerOrganisatieType)))
            .ReverseMap();
        CreateMap<ConversatieLogboekZoekbericht, ConversatieLogboekZoekberichtModel>()
            .ReverseMap();
        CreateMap<LogboekBericht, LogboekBerichtModel<Berichttype>>().ReverseMap();
        CreateMap<ConversatieLogboekBericht, ConversatieLogboekBerichtModel<Berichttype>>()
            .ForMember(l => l.Staat, cfg => cfg.MapFrom(x => x.Staat.ToString())).ReverseMap();

        CreateMap<MessageboxConfirmatieBericht, MessageboxConfirmatieBerichtModel>().ReverseMap();
        CreateMap<MessageboxConfirmatieResultBericht, MessageboxConfirmatieResultBerichtModel>()
            .ReverseMap();
        CreateMap<MessageboxBerichtinformatie, MessageboxBerichtinformatieModel>().ReverseMap();
        CreateMap<MessageboxBericht, MessageboxBerichtModel>()
            .ForMember(x => x.Bijlagereferentienummers, cfg => cfg.Ignore())
            .ForMember(x => x.Vervallen, cfg => cfg.Ignore())
            .ReverseMap();

        CreateMap<ShvKnooppuntFoutbericht, ShvKnooppuntFoutberichtModel>().ReverseMap();
        CreateMap<ShvKnooppuntFout, ShvKnooppuntFoutModel>().ReverseMap();
    }
}